@@ -37,29 +37,20 @@ typedef struct laser_type {
   int x2, y2;
 } laser_type;
 
-enum {
-  OPER_ADD,
-  OPER_SUB,
-  OPER_MULT,
-  OPER_DIV,
-  NUM_OPERS
-};
 
-extern char operchars[NUM_OPERS];
-
-extern char * oper_opts[NUM_OPERS];
-
-extern char * oper_alt_opts[NUM_OPERS];
 
 enum {
-  Q_RANGE_1_5,
-  Q_RANGE_6_12,
-  Q_RANGE_13_20,
-  NUM_Q_RANGES
+  GAME_IN_PROGRESS,
+  GAME_OVER_WON,
+  GAME_OVER_LOST,
+  GAME_OVER_OTHER,
+  GAME_OVER_ESCAPE,
+  GAME_OVER_WINDOW_CLOSE,
+  GAME_OVER_ERROR
 };
 
 int game(void);
-
+/* draw_nums() is used in options.c so need extern linkage */
 void draw_nums(char* str, int x, int y);
 
 #endif
