@@ -18,6 +18,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+
+#include "tuxmath.h"
 #include "setup.h"
 #include "title.h"
 #include "game.h"
@@ -25,11 +27,11 @@
 #include "credits.h"
 
 
+/* global data: */
+
 int main(int argc, char * argv[])
 {
   int cmd, done;
-
-
   setup(argc, argv);
   
   done = 0;
@@ -49,8 +51,7 @@ int main(int argc, char * argv[])
   }
   while (!done);
   
-  SDL_Quit();
-
+  cleanup();
   return 0;
 }
 
